@@ -638,7 +638,7 @@ class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
     _API_IGNORE = (
         "ip_address", "endpoint", "rsindex", "vsindex", "index", "status",
-        "subvs_data", "subvs_entries", "real_servers", "cert", "rsminimum",
+        "subvs_data", "subvs_entries", "real_servers", "cert",
         "checkuse1_1", "mastervsid"
     )
 
